;;; init.el --- .Emacs Configuration -*- lexical-binding: t -*-
;;; Commentary:
;;
;; Emacs!!!

;;; Code:
(package-initialize)

(when (version<= emacs-version "24")
  (error "This is made form Emacs >=24"))

(defconst emacs-start-time (current-time))
(add-to-list 'load-path (expand-file-name "~/.emacs.d/modules/" user-emacs-directory))

;;; Raise garbage collection threshold after init
(add-hook 'after-init-hook
	  (lambda () (setq gc-cons-threshold local/gc-cons-threshold)))

;;; Custom variables
(setq custom-file (expand-file-name "custom.el" user-emacs-directory))
;;; Custom settings
(setq settings-file (expand-file-name "settings.el" user-emacs-directory))

;;; Loads settings file
(when (file-exists-p custom-file)
  (load settings-file))
;;;------------------------------
;;; Features
;;;------------------------------
(require 'init-security)
(require 'init-elpa)
;; theme
(require 'init-theme)
;; Utils
(require 'init-utils)
;; GUI
(require 'init-nlinum)
(require 'init-gui)
(require 'init-editing-utils)
(require 'init-diminish)
(require 'init-ecb)
(require 'init-modeline)
(require 'init-indent-guides)
(require 'init-icons)
(require 'init-neotree)
;; Tools
(require 'init-flycheck)
(require 'init-whitespace)
(require 'init-emmet-mode)
(require 'init-nginx)
(require 'init-git)
;;(require 'init-editorconfig)
;; Languages
(require 'init-ccc)
(require 'init-crystal)
(require 'init-html)
(require 'init-markdown)
(require 'init-php)
(require 'init-python)
(require 'init-pkgbuild)
(require 'init-less)
(require 'init-sass)
(require 'init-scss)
(require 'init-yaml)
;; Plus
(require 'init-rainbow)
(require 'init-web-mode)
(require 'init-ready)
(require 'init-dokuwiki)

;;; Loads custom file
(when (file-exists-p custom-file)
  (load custom-file))

(when window-system
  (let ((elapsed (float-time (time-subtract (current-time)
                                            emacs-start-time))))
    (message "[STARTUP] Loading %s ... done (%.3fs)" load-file-name elapsed)))

(provide 'init)
;; Local Variables:
;; byte-compile-warnings: (not free-vars)
;; End:
;;; init.el ends here
